Range-v3: ranges::v3::ostreambuf_iterator< Char, Traits > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | Public Member Functions | List of all members
ranges::v3::ostreambuf_iterator< Char, Traits > Struct Template Reference
Utility

## Public Types
typedef Char | char_type
typedef ptrdiff_t | difference_type
typedef std::basic_ostream< Char, Traits > | ostream_type
typedef std::basic_streambuf< Char, Traits > | streambuf_type
typedef Traits | traits_type

## Public Member Functions
bool | failed () const noexcept
ostreambuf_iterator & | operator* ()
ostreambuf_iterator & | operator++ ()
ostreambuf_iterator & | operator++ (int)
ostreambuf_iterator & | operator= (Char c)
| ostreambuf_iterator (ostream_type &s) noexcept
| ostreambuf_iterator (streambuf_type *s) noexcept